@@ -37,6 +37,12 @@ class DescribeDomainUsageDataRequest(RpcRequest):
 	def set_StartTime(self,StartTime):
 		self.add_query_param('StartTime',StartTime)
 
+	def get_Type(self):
+		return self.get_query_params().get('Type')
+
+	def set_Type(self,Type):
+		self.add_query_param('Type',Type)
+
 	def get_DataProtocol(self):
 		return self.get_query_params().get('DataProtocol')
 
